@@ -969,7 +969,7 @@ def printTable(list, info):
     error_table.align[1] = '1'
     error_table.border = True
     error_table.junction_char = '+'
-    error_table.horizontal_char = '——'
+    error_table.horizontal_char = '-'
     error_table.vertical_char = '|'
     debugInfo(error_table)
     debugInfo("[!] 以上是{0}".format(info))
